<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing_ad');

// 记录访问日志
record_log('访问广告投放管理页面');

// 添加/编辑广告投放处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加广告投放
    if ($_POST['action'] == 'add') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $platform = isset($_POST['platform']) ? intval($_POST['platform']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $target_count = isset($_POST['target_count']) ? intval($_POST['target_count']) : 0;

        if ($campaign_id <= 0 || empty($name) || empty($content) || empty($start_date)) {
            $error = '请填写完整的广告投放信息！';
        } else {
            try {
                // 根据平台设置渠道类型
                $channel_type = 0;
                if ($platform == 1) $channel_type = 3; // 社交媒体
                elseif ($platform == 2) $channel_type = 4; // 搜索引擎
                elseif ($platform == 3) $channel_type = 5; // 抖音

                // 添加广告投放
                $stmt = $pdo->prepare("
                    INSERT INTO mkt_channels 
                    (campaign_id, type, name, content, send_time, status, target_count, actual_count) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, 0)
                ");
                $result = $stmt->execute([
                    $campaign_id,
                    $channel_type,
                    $name,
                    $content,
                    $start_date,
                    $status,
                    $target_count
                ]);

                if ($result) {
                    $platform_text = '';
                    if ($platform == 1) $platform_text = '社交媒体';
                    elseif ($platform == 2) $platform_text = 'Google Ads';
                    elseif ($platform == 3) $platform_text = '抖音';

                    record_log("添加{$platform_text}广告：{$name}");
                    $success = "广告投放添加成功！";
                    // 重定向到没有参数的页面
                    header('Location: ad.php?success=add');
                    exit;
                } else {
                    $error = '广告投放添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑广告投放
    elseif ($_POST['action'] == 'edit') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $platform = isset($_POST['platform']) ? intval($_POST['platform']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $target_count = isset($_POST['target_count']) ? intval($_POST['target_count']) : 0;
        $actual_count = isset($_POST['actual_count']) ? intval($_POST['actual_count']) : 0;
        $reach = isset($_POST['reach']) ? intval($_POST['reach']) : 0;
        $click = isset($_POST['click']) ? intval($_POST['click']) : 0;
        $conversion = isset($_POST['conversion']) ? intval($_POST['conversion']) : 0;

        if ($channel_id <= 0 || $campaign_id <= 0 || empty($name) || empty($content) || empty($start_date)) {
            $error = '请填写完整的广告投放信息！';
        } else {
            try {
                // 根据平台设置渠道类型
                $channel_type = 0;
                if ($platform == 1) $channel_type = 3; // 社交媒体
                elseif ($platform == 2) $channel_type = 4; // 搜索引擎
                elseif ($platform == 3) $channel_type = 5; // 抖音

                // 更新广告投放信息
                $stmt = $pdo->prepare("
                    UPDATE mkt_channels 
                    SET campaign_id = ?, type = ?, name = ?, content = ?, 
                        send_time = ?, status = ?, target_count = ?, actual_count = ?
                    WHERE id = ?
                ");
                $result = $stmt->execute([
                    $campaign_id,
                    $channel_type,
                    $name,
                    $content,
                    $start_date,
                    $status,
                    $target_count,
                    $actual_count,
                    $channel_id
                ]);

                if ($result) {
                    // 更新或创建效果数据
                    $stmt = $pdo->prepare("
                        INSERT INTO mkt_results 
                        (campaign_id, channel_id, reach, click, conversion) 
                        VALUES (?, ?, ?, ?, ?)
                        ON DUPLICATE KEY UPDATE 
                        reach = VALUES(reach), 
                        click = VALUES(click), 
                        conversion = VALUES(conversion)
                    ");
                    $stmt->execute([$campaign_id, $channel_id, $reach, $click, $conversion]);

                    $platform_text = '';
                    if ($platform == 1) $platform_text = '社交媒体';
                    elseif ($platform == 2) $platform_text = 'Google Ads';
                    elseif ($platform == 3) $platform_text = '抖音';

                    record_log("编辑{$platform_text}广告：{$name}");
                    $success = "广告投放信息更新成功！";
                    // 重定向到没有参数的页面
                    header('Location: ad.php?success=edit');
                    exit;
                } else {
                    $error = '广告投放信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除广告投放
    elseif ($_POST['action'] == 'delete') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;

        if ($channel_id <= 0) {
            $error = '无效的广告ID！';
        } else {
            try {
                // 获取广告名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name, type FROM mkt_channels WHERE id = ?");
                $stmt->execute([$channel_id]);
                $channel = $stmt->fetch();

                if (!$channel) {
                    $error = '广告投放不存在！';
                } else {
                    // 删除广告投放
                    $stmt = $pdo->prepare("DELETE FROM mkt_channels WHERE id = ?");
                    $result = $stmt->execute([$channel_id]);

                    if ($result) {
                        $platform_text = '';
                        if ($channel['type'] == 3) $platform_text = '社交媒体';
                        elseif ($channel['type'] == 4) $platform_text = 'Google Ads';
                        elseif ($channel['type'] == 5) $platform_text = '抖音';

                        record_log("删除{$platform_text}广告：{$channel['name']}");
                        $success = "广告投放删除成功！";
                    } else {
                        $error = '广告投放删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有活动（用于关联广告投放）
try {
    $stmt = $pdo->query("SELECT id, name FROM mkt_campaigns WHERE status IN (1, 2) ORDER BY id DESC");
    $campaigns = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活动列表失败：' . $e->getMessage();
    $campaigns = [];
}

// 获取所有广告投放
try {
    $stmt = $pdo->query("
        SELECT ch.*, c.name as campaign_name, r.reach, r.click, r.conversion 
        FROM mkt_channels ch
        JOIN mkt_campaigns c ON ch.campaign_id = c.id
        LEFT JOIN mkt_results r ON ch.id = r.channel_id
        WHERE ch.type IN (3, 4, 5)
        ORDER BY ch.id DESC
    ");
    $ads = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取广告投放列表失败：' . $e->getMessage();
    $ads = [];
}

// 判断是否显示表单
$show_form = false;
$edit_ad = null;

// 编辑广告投放时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("
            SELECT ch.*, r.reach, r.click, r.conversion 
            FROM mkt_channels ch
            LEFT JOIN mkt_results r ON ch.id = r.channel_id
            WHERE ch.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_ad = $stmt->fetch();
        if (!$edit_ad) {
            $error = '广告投放不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取广告投放信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加广告投放时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
    // 预设平台类型
    $preset_platform = isset($_GET['platform']) ? intval($_GET['platform']) : 1;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '广告投放添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '广告投放信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>广告投放管理</h2>
            <div class="breadcrumb">
                <a href="index.php">市场营销管理</a> &gt; 广告投放管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="ad.php?action=add&platform=1" class="btn btn-add">添加社交媒体广告</a>
                <a href="ad.php?action=add&platform=2" class="btn btn-add">添加Google Ads</a>
                <a href="ad.php?action=add&platform=3" class="btn btn-add">添加抖音广告</a>
            </div>

            <!-- 添加/编辑广告投放表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3>
                        <?php
                        if ($edit_ad) {
                            if ($edit_ad['type'] == 3) echo '编辑社交媒体广告';
                            elseif ($edit_ad['type'] == 4) echo '编辑Google Ads';
                            elseif ($edit_ad['type'] == 5) echo '编辑抖音广告';
                            else echo '编辑广告投放';
                        } else {
                            if ($preset_platform == 1) echo '添加社交媒体广告';
                            elseif ($preset_platform == 2) echo '添加Google Ads';
                            elseif ($preset_platform == 3) echo '添加抖音广告';
                            else echo '添加广告投放';
                        }
                        ?>
                    </h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_ad ? 'edit' : 'add'; ?>">
                        <?php if ($edit_ad): ?>
                            <input type="hidden" name="channel_id" value="<?php echo $edit_ad['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="campaign_id">所属活动：</label>
                            <select id="campaign_id" name="campaign_id" required>
                                <option value="">请选择活动</option>
                                <?php foreach ($campaigns as $campaign): ?>
                                    <option value="<?php echo $campaign['id']; ?>" <?php echo ($edit_ad && $edit_ad['campaign_id'] == $campaign['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($campaign['name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="platform">平台类型：</label>
                            <select id="platform" name="platform">
                                <option value="1" <?php echo (($edit_ad && $edit_ad['type'] == 3) || (!$edit_ad && $preset_platform == 1)) ? 'selected' : ''; ?>>社交媒体</option>
                                <option value="2" <?php echo (($edit_ad && $edit_ad['type'] == 4) || (!$edit_ad && $preset_platform == 2)) ? 'selected' : ''; ?>>Google Ads</option>
                                <option value="3" <?php echo (($edit_ad && $edit_ad['type'] == 5) || (!$edit_ad && $preset_platform == 3)) ? 'selected' : ''; ?>>抖音</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">广告名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_ad ? htmlspecialchars($edit_ad['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="content">广告内容：</label>
                            <textarea id="content" name="content" rows="4" required><?php echo $edit_ad ? htmlspecialchars($edit_ad['content']) : ''; ?></textarea>
                            <small>可在内容中包含目标受众、预算等附加信息</small>
                        </div>

                        <div class="form-group">
                            <label for="target_count">目标覆盖人数：</label>
                            <input type="number" id="target_count" name="target_count" min="0" value="<?php echo $edit_ad ? htmlspecialchars($edit_ad['target_count']) : '0'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="datetime-local" id="start_date" name="start_date" value="<?php echo $edit_ad && $edit_ad['send_time'] ? date('Y-m-d\TH:i', strtotime($edit_ad['send_time'])) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_ad && $edit_ad['status'] == 1) ? 'selected' : ''; ?>>准备中</option>
                                <option value="2" <?php echo ($edit_ad && $edit_ad['status'] == 2) ? 'selected' : ''; ?>>投放中</option>
                                <option value="3" <?php echo ($edit_ad && $edit_ad['status'] == 3) ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <?php if ($edit_ad): ?>
                            <div class="form-group">
                                <label for="actual_count">实际覆盖人数：</label>
                                <input type="number" id="actual_count" name="actual_count" min="0" value="<?php echo $edit_ad ? htmlspecialchars($edit_ad['actual_count']) : '0'; ?>">
                            </div>

                            <div class="form-group">
                                <label for="reach">触达人数：</label>
                                <input type="number" id="reach" name="reach" min="0" value="<?php echo isset($edit_ad['reach']) ? htmlspecialchars($edit_ad['reach']) : 0; ?>">
                            </div>

                            <div class="form-group">
                                <label for="click">点击次数：</label>
                                <input type="number" id="click" name="click" min="0" value="<?php echo isset($edit_ad['click']) ? htmlspecialchars($edit_ad['click']) : 0; ?>">
                            </div>

                            <div class="form-group">
                                <label for="conversion">转化次数：</label>
                                <input type="number" id="conversion" name="conversion" min="0" value="<?php echo isset($edit_ad['conversion']) ? htmlspecialchars($edit_ad['conversion']) : 0; ?>">
                            </div>
                        <?php endif; ?>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="ad.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 广告投放列表 -->
            <div class="table-container">
                <h3>广告投放列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>平台</th>
                            <th>广告名称</th>
                            <th>所属活动</th>
                            <th>开始日期</th>
                            <th>目标覆盖</th>
                            <th>实际覆盖</th>
                            <th>触达人数</th>
                            <th>点击</th>
                            <th>转化</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($ads)): ?>
                            <tr>
                                <td colspan="12" class="text-center">暂无广告投放数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($ads as $ad): ?>
                                <tr>
                                    <td><?php echo $ad['id']; ?></td>
                                    <td>
                                        <?php
                                        if ($ad['type'] == 3) echo '社交媒体';
                                        elseif ($ad['type'] == 4) echo 'Google Ads';
                                        elseif ($ad['type'] == 5) echo '抖音';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($ad['name']); ?></td>
                                    <td><?php echo htmlspecialchars($ad['campaign_name']); ?></td>
                                    <td><?php echo $ad['send_time'] ? date('Y-m-d', strtotime($ad['send_time'])) : '-'; ?></td>
                                    <td><?php echo $ad['target_count'] ?: 0; ?></td>
                                    <td><?php echo $ad['actual_count'] ?: 0; ?></td>
                                    <td><?php echo isset($ad['reach']) ? $ad['reach'] : 0; ?></td>
                                    <td><?php echo isset($ad['click']) ? $ad['click'] : 0; ?></td>
                                    <td><?php echo isset($ad['conversion']) ? $ad['conversion'] : 0; ?></td>
                                    <td>
                                        <?php
                                        if ($ad['status'] == 1) echo '<span class="status-pending">准备中</span>';
                                        elseif ($ad['status'] == 2) echo '<span class="status-active">投放中</span>';
                                        elseif ($ad['status'] == 3) echo '<span class="status-inactive">已完成</span>';
                                        ?>
                                    </td>
                                    <td>
                                        <a href="ad.php?action=edit&id=<?php echo $ad['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="channel_id" value="<?php echo $ad['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此广告投放吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 广告投放说明 -->
            <div class="info-box">
                <h3>广告投放说明</h3>
                <ul>
                    <li><strong>社交媒体广告</strong>：在各大社交媒体平台（如微信、微博、Facebook等）投放的广告。</li>
                    <li><strong>Google Ads</strong>：在Google搜索引擎和Google展示广告网络投放的广告。</li>
                    <li><strong>抖音广告</strong>：在抖音平台投放的短视频广告。</li>
                    <li><strong>内容填写建议</strong>：在广告内容中可以包含目标受众描述、预算等信息。</li>
                    <li><strong>状态说明</strong>：
                        <ul>
                            <li><em>准备中</em>：广告内容已创建，但尚未正式投放。</li>
                            <li><em>投放中</em>：广告正在目标平台投放中。</li>
                            <li><em>已完成</em>：广告投放已结束。</li>
                        </ul>
                    </li>
                    <li><strong>数据指标</strong>：
                        <ul>
                            <li><em>目标覆盖</em>：计划覆盖的用户数量。</li>
                            <li><em>实际覆盖</em>：实际覆盖的用户数量。</li>
                            <li><em>触达人数</em>：广告被展示给的用户数量。</li>
                            <li><em>点击次数</em>：用户点击广告的次数。</li>
                            <li><em>转化次数</em>：完成目标行为（如注册、购买）的次数。</li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>