<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing_email');

// 记录访问日志
record_log('访问邮件和短信营销页面');

// 添加/编辑营销邮件或短信处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加营销邮件或短信
    if ($_POST['action'] == 'add') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $send_time = isset($_POST['send_time']) ? trim($_POST['send_time']) : '';
        $target_count = isset($_POST['target_count']) ? intval($_POST['target_count']) : 0;

        if ($campaign_id <= 0 || empty($name) || empty($content)) {
            $error = '请填写完整的营销信息！';
        } else {
            try {
                // 添加营销邮件或短信
                $stmt = $pdo->prepare("INSERT INTO mkt_channels (campaign_id, type, name, content, send_time, status, target_count) VALUES (?, ?, ?, ?, ?, 1, ?)");
                $result = $stmt->execute([$campaign_id, $type, $name, $content, $send_time, $target_count]);

                if ($result) {
                    $type_text = $type == 1 ? '邮件' : '短信';
                    record_log("添加营销{$type_text}：{$name}");
                    $success = "营销{$type_text}添加成功！";
                    // 重定向到没有参数的页面
                    header('Location: email.php?success=add');
                    exit;
                } else {
                    $error = '添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑营销邮件或短信
    elseif ($_POST['action'] == 'edit') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $send_time = isset($_POST['send_time']) ? trim($_POST['send_time']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $target_count = isset($_POST['target_count']) ? intval($_POST['target_count']) : 0;
        $actual_count = isset($_POST['actual_count']) ? intval($_POST['actual_count']) : 0;

        if ($channel_id <= 0 || $campaign_id <= 0 || empty($name) || empty($content)) {
            $error = '请填写完整的营销信息！';
        } else {
            try {
                // 更新营销邮件或短信信息
                $stmt = $pdo->prepare("UPDATE mkt_channels SET campaign_id = ?, type = ?, name = ?, content = ?, send_time = ?, status = ?, target_count = ?, actual_count = ? WHERE id = ?");
                $result = $stmt->execute([$campaign_id, $type, $name, $content, $send_time, $status, $target_count, $actual_count, $channel_id]);

                if ($result) {
                    $type_text = $type == 1 ? '邮件' : '短信';
                    record_log("编辑营销{$type_text}：{$name}");
                    $success = "营销{$type_text}信息更新成功！";
                    // 重定向到没有参数的页面
                    header('Location: email.php?success=edit');
                    exit;
                } else {
                    $error = '更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除营销邮件或短信
    elseif ($_POST['action'] == 'delete') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;

        if ($channel_id <= 0) {
            $error = '无效的ID！';
        } else {
            try {
                // 获取名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name, type FROM mkt_channels WHERE id = ?");
                $stmt->execute([$channel_id]);
                $channel = $stmt->fetch();

                if (!$channel) {
                    $error = '记录不存在！';
                } else {
                    // 删除营销邮件或短信
                    $stmt = $pdo->prepare("DELETE FROM mkt_channels WHERE id = ?");
                    $result = $stmt->execute([$channel_id]);

                    if ($result) {
                        $type_text = $channel['type'] == 1 ? '邮件' : '短信';
                        record_log("删除营销{$type_text}：{$channel['name']}");
                        $success = "营销{$type_text}删除成功！";
                    } else {
                        $error = '删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 发送营销邮件或短信
    elseif ($_POST['action'] == 'send') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;

        if ($channel_id <= 0) {
            $error = '无效的ID！';
        } else {
            try {
                // 获取渠道信息
                $stmt = $pdo->prepare("SELECT * FROM mkt_channels WHERE id = ?");
                $stmt->execute([$channel_id]);
                $channel = $stmt->fetch();

                if (!$channel) {
                    $error = '记录不存在！';
                } elseif ($channel['status'] != 1) {
                    $error = '只能发送处于准备中状态的邮件或短信！';
                } else {
                    // 模拟发送过程，更新状态为已发送
                    $stmt = $pdo->prepare("UPDATE mkt_channels SET status = 2, send_time = NOW(), actual_count = target_count WHERE id = ?");
                    $result = $stmt->execute([$channel_id]);

                    if ($result) {
                        $type_text = $channel['type'] == 1 ? '邮件' : '短信';
                        record_log("发送营销{$type_text}：{$channel['name']}");
                        $success = "营销{$type_text}发送成功！";
                    } else {
                        $error = '发送失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有活动（用于关联营销邮件或短信）
try {
    $stmt = $pdo->query("SELECT id, name FROM mkt_campaigns WHERE status IN (1, 2) ORDER BY id DESC");
    $campaigns = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活动列表失败：' . $e->getMessage();
    $campaigns = [];
}

// 获取所有营销邮件和短信
try {
    $stmt = $pdo->query("
        SELECT ch.*, c.name as campaign_name 
        FROM mkt_channels ch
        JOIN mkt_campaigns c ON ch.campaign_id = c.id
        WHERE ch.type IN (1, 2)
        ORDER BY ch.id DESC
    ");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取邮件和短信列表失败：' . $e->getMessage();
    $channels = [];
}

// 判断是否显示表单
$show_form = false;
$edit_channel = null;

// 编辑邮件或短信时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM mkt_channels WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_channel = $stmt->fetch();
        if (!$edit_channel) {
            $error = '记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加邮件或短信时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
    // 预设类型参数
    $preset_type = isset($_GET['type']) && ($_GET['type'] == 1 || $_GET['type'] == 2) ? intval($_GET['type']) : 1;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>邮件和短信营销</h2>
            <div class="breadcrumb">
                <a href="index.php">市场营销管理</a> &gt; 邮件和短信营销
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="email.php?action=add&type=1" class="btn btn-add">添加邮件营销</a>
                <a href="email.php?action=add&type=2" class="btn btn-add">添加短信营销</a>
            </div>

            <!-- 添加/编辑邮件或短信表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3>
                        <?php
                        if ($edit_channel) {
                            echo $edit_channel['type'] == 1 ? '编辑邮件营销' : '编辑短信营销';
                        } else {
                            echo $preset_type == 1 ? '添加邮件营销' : '添加短信营销';
                        }
                        ?>
                    </h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_channel ? 'edit' : 'add'; ?>">
                        <?php if ($edit_channel): ?>
                            <input type="hidden" name="channel_id" value="<?php echo $edit_channel['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="campaign_id">所属活动：</label>
                            <select id="campaign_id" name="campaign_id" required>
                                <option value="">请选择活动</option>
                                <?php foreach ($campaigns as $campaign): ?>
                                    <option value="<?php echo $campaign['id']; ?>" <?php echo ($edit_channel && $edit_channel['campaign_id'] == $campaign['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($campaign['name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">类型：</label>
                            <select id="type" name="type">
                                <option value="1" <?php echo (($edit_channel && $edit_channel['type'] == 1) || (!$edit_channel && $preset_type == 1)) ? 'selected' : ''; ?>>邮件</option>
                                <option value="2" <?php echo (($edit_channel && $edit_channel['type'] == 2) || (!$edit_channel && $preset_type == 2)) ? 'selected' : ''; ?>>短信</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_channel ? htmlspecialchars($edit_channel['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="content">内容：</label>
                            <textarea id="content" name="content" rows="6" required><?php echo $edit_channel ? htmlspecialchars($edit_channel['content']) : ''; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="send_time">计划发送时间：</label>
                            <input type="datetime-local" id="send_time" name="send_time" value="<?php echo $edit_channel && $edit_channel['send_time'] ? date('Y-m-d\TH:i', strtotime($edit_channel['send_time'])) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="target_count">目标发送数量：</label>
                            <input type="number" id="target_count" name="target_count" min="0" value="<?php echo $edit_channel ? htmlspecialchars($edit_channel['target_count']) : ''; ?>">
                        </div>

                        <?php if ($edit_channel): ?>
                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_channel['status'] == 1) ? 'selected' : ''; ?>>准备中</option>
                                    <option value="2" <?php echo ($edit_channel['status'] == 2) ? 'selected' : ''; ?>>已发送</option>
                                    <option value="3" <?php echo ($edit_channel['status'] == 3) ? 'selected' : ''; ?>>已完成</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="actual_count">实际发送数量：</label>
                                <input type="number" id="actual_count" name="actual_count" min="0" value="<?php echo htmlspecialchars($edit_channel['actual_count']); ?>">
                            </div>
                        <?php endif; ?>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="email.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 邮件和短信列表 -->
            <div class="table-container">
                <h3>邮件和短信列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>类型</th>
                            <th>名称</th>
                            <th>所属活动</th>
                            <th>发送时间</th>
                            <th>目标数量</th>
                            <th>实际数量</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($channels)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($channels as $channel): ?>
                                <tr>
                                    <td><?php echo $channel['id']; ?></td>
                                    <td><?php echo $channel['type'] == 1 ? '邮件' : '短信'; ?></td>
                                    <td><?php echo htmlspecialchars($channel['name']); ?></td>
                                    <td><?php echo htmlspecialchars($channel['campaign_name']); ?></td>
                                    <td><?php echo $channel['send_time'] ? date('Y-m-d H:i', strtotime($channel['send_time'])) : '-'; ?></td>
                                    <td><?php echo $channel['target_count'] ?: 0; ?></td>
                                    <td><?php echo $channel['actual_count'] ?: 0; ?></td>
                                    <td>
                                        <?php
                                        if ($channel['status'] == 1) echo '<span class="status-pending">准备中</span>';
                                        elseif ($channel['status'] == 2) echo '<span class="status-active">已发送</span>';
                                        elseif ($channel['status'] == 3) echo '<span class="status-inactive">已完成</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($channel['create_time'])); ?></td>
                                    <td>
                                        <a href="email.php?action=edit&id=<?php echo $channel['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="channel_id" value="<?php echo $channel['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此记录吗？');">删除</button>
                                        </form>
                                        <?php if ($channel['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="send">
                                                <input type="hidden" name="channel_id" value="<?php echo $channel['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定要立即发送吗？');">发送</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 邮件和短信营销说明 -->
            <div class="info-box">
                <h3>邮件和短信营销说明</h3>
                <ul>
                    <li><strong>邮件营销</strong>：用于批量发送营销邮件，支持HTML格式的内容。</li>
                    <li><strong>短信营销</strong>：用于批量发送营销短信，短信内容受字数限制，建议简短明了。</li>
                    <li><strong>状态说明</strong>：
                        <ul>
                            <li><em>准备中</em>：邮件或短信还在准备阶段，可以编辑内容并发送。</li>
                            <li><em>已发送</em>：邮件或短信已发送给目标受众。</li>
                            <li><em>已完成</em>：营销活动已结束，不再接收反馈数据。</li>
                        </ul>
                    </li>
                    <li><strong>注意事项</strong>：发送营销邮件和短信需遵守相关法律法规，确保用户已授权接收营销信息。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>