<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order');

// 记录访问日志
record_log('访问订单管理页面');

// 获取订单总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM order_orders");
    $order_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取订单数据失败：' . $e->getMessage();
    $order_count = ['count' => 0];
}

// 获取待处理订单数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM order_orders WHERE status = 1");
    $pending_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取待处理订单数据失败：' . $e->getMessage();
    $pending_count = ['count' => 0];
}

// 获取订单总金额
try {
    $stmt = $pdo->query("SELECT SUM(amount) as total FROM order_orders WHERE status != 5");
    $order_amount = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取订单金额数据失败：' . $e->getMessage();
    $order_amount = ['total' => 0];
}

// 获取待开发票数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM order_invoices WHERE status = 1");
    $invoice_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取发票数据失败：' . $e->getMessage();
    $invoice_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>订单概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>订单总数</h3>
                    <div class="number"><?php echo $order_count['count']; ?></div>
                    <div class="desc">所有订单数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>待处理订单</h3>
                    <div class="number"><?php echo $pending_count['count']; ?></div>
                    <div class="desc">待支付订单数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>订单总金额</h3>
                    <div class="number"><?php echo number_format($order_amount['total'] ?: 0, 2); ?></div>
                    <div class="desc">不含已取消订单</div>
                </div>

                <div class="dashboard-card">
                    <h3>待开发票</h3>
                    <div class="number"><?php echo $invoice_count['count']; ?></div>
                    <div class="desc">申请中的发票数量</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="entry.php" class="function-link">
                    <h3>订单录入</h3>
                </a>
                <a href="review.php" class="function-link">
                    <h3>订单审核</h3>
                </a>
                <a href="status.php" class="function-link">
                    <h3>订单状态管理</h3>
                </a>
                <a href="invoice.php" class="function-link">
                    <h3>发票管理</h3>
                </a>
                <a href="refund.php" class="function-link">
                    <h3>退款与退货</h3>
                </a>
            </div>

            <h2>最近订单记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>客户名称</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT o.*, c.client_name, u.username 
                                            FROM order_orders o
                                            JOIN crm_clients c ON o.client_id = c.id 
                                            JOIN sys_users u ON o.creator_id = u.id 
                                            ORDER BY o.create_time DESC LIMIT 5");
                            $orders = $stmt->fetchAll();

                            if (empty($orders)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无订单记录</td>
                                </tr>
                                <?php else:
                                foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo htmlspecialchars($order['client_name']); ?></td>
                                        <td><?php echo number_format($order['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            if ($order['status'] == 1) echo '<span class="status-pending">待支付</span>';
                                            elseif ($order['status'] == 2) echo '<span class="status-pending">已支付</span>';
                                            elseif ($order['status'] == 3) echo '<span class="status-pending">已发货</span>';
                                            elseif ($order['status'] == 4) echo '<span class="status-active">已完成</span>';
                                            elseif ($order['status'] == 5) echo '<span class="status-inactive">已取消</span>';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($order['username']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取订单记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近发票记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>发票号码</th>
                            <th>订单编号</th>
                            <th>发票金额</th>
                            <th>发票抬头</th>
                            <th>状态</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT i.*, o.order_no 
                                            FROM order_invoices i
                                            JOIN order_orders o ON i.order_id = o.id 
                                            ORDER BY i.create_time DESC LIMIT 5");
                            $invoices = $stmt->fetchAll();

                            if (empty($invoices)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无发票记录</td>
                                </tr>
                                <?php else:
                                foreach ($invoices as $invoice): ?>
                                    <tr>
                                        <td><?php echo $invoice['invoice_no'] ? htmlspecialchars($invoice['invoice_no']) : '未生成'; ?></td>
                                        <td><?php echo htmlspecialchars($invoice['order_no']); ?></td>
                                        <td><?php echo number_format($invoice['amount'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($invoice['title']); ?></td>
                                        <td>
                                            <?php
                                            if ($invoice['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                            elseif ($invoice['status'] == 2) echo '<span class="status-pending">已开票</span>';
                                            elseif ($invoice['status'] == 3) echo '<span class="status-active">已寄出</span>';
                                            elseif ($invoice['status'] == 4) echo '<span class="status-inactive">已取消</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($invoice['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取发票记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>