<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('performance');

// 记录访问日志
record_log('访问人员绩效与KPI页面');

// 检查当前用户是否为管理员(假设角色ID=1为管理员)
$is_admin = ($_SESSION['role_id'] == 1);
$filter_user = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0;

// 获取当前用户的考核记录数量
try {
    if ($is_admin && $filter_user == 0) {
        // 管理员查看所有数据
        $stmt = $pdo->query("
            SELECT COUNT(*) as count 
            FROM perf_assessments 
        ");
    } else if ($is_admin && $filter_user > 0) {
        // 管理员查看特定用户数据
        $stmt = $pdo->prepare("
            SELECT COUNT(*) as count 
            FROM perf_assessments 
            WHERE user_id = ?
        ");
        $stmt->execute([$filter_user]);
    } else {
        // 普通用户查看自己的数据
        $stmt = $pdo->prepare("
            SELECT COUNT(*) as count 
            FROM perf_assessments 
            WHERE user_id = ?
        ");
        $stmt->execute([$_SESSION['user_id']]);
    }
    $assessment_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取考核记录数据失败：' . $e->getMessage();
    $assessment_count = ['count' => 0];
}

// 获取当前用户的激励记录数量
try {
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM perf_incentives 
        WHERE user_id = ?
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $incentive_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取激励记录数据失败：' . $e->getMessage();
    $incentive_count = ['count' => 0];
}

// 获取当前用户所在团队数量
try {
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM perf_teams 
        WHERE leader_id = ? OR members LIKE ?
    ");
    $stmt->execute([$_SESSION['user_id'], '%,' . $_SESSION['user_id'] . ',%']);
    $team_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取团队数据失败：' . $e->getMessage();
    $team_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>人员绩效与KPI</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if ($is_admin): ?>
                <div class="filter-form">
                    <h3>用户筛选</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="user_id">选择用户：</label>
                                <select id="user_id" name="user_id">
                                    <option value="0">所有用户</option>
                                    <?php
                                    // 获取所有用户列表
                                    try {
                                        $stmt = $pdo->query("SELECT id, username FROM sys_users ORDER BY id");
                                        $users_list = $stmt->fetchAll();
                                        foreach ($users_list as $user) {
                                            echo '<option value="' . $user['id'] . '"' .
                                                ($filter_user == $user['id'] ? ' selected' : '') . '>' .
                                                htmlspecialchars($user['username']) . ' (ID:' . $user['id'] . ')</option>';
                                        }
                                    } catch (PDOException $e) {
                                        echo '<option value="0">获取用户列表失败</option>';
                                    }
                                    ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="index.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <h2>绩效概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>绩效考核</h3>
                    <div class="number"><?php echo $assessment_count['count']; ?></div>
                    <div class="desc">历史考核记录</div>
                </div>

                <div class="dashboard-card">
                    <h3>激励记录</h3>
                    <div class="number"><?php echo $incentive_count['count']; ?></div>
                    <div class="desc">奖金与提成记录</div>
                </div>

                <div class="dashboard-card">
                    <h3>所在团队</h3>
                    <div class="number"><?php echo $team_count['count']; ?></div>
                    <div class="desc">参与的团队数量</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="target.php" class="function-link">
                    <h3>销售目标设定</h3>
                </a>
                <a href="assess.php" class="function-link">
                    <h3>业绩考核</h3>
                </a>
                <a href="incentive.php" class="function-link">
                    <h3>激励机制</h3>
                </a>
                <a href="../task/team.php" class="function-link">
                    <h3>团队管理</h3>
                </a>
            </div>

            <h2>最近考核记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>年月</th>
                            <th>销售目标</th>
                            <th>实际销售</th>
                            <th>客户目标</th>
                            <th>实际客户</th>
                            <th>得分</th>
                            <th>等级</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->prepare("
                                SELECT *, 
                                       CONCAT(year, '年', month, '月') as assessment_period,
                                       CASE 
                                           WHEN level = 1 THEN 'A'
                                           WHEN level = 2 THEN 'B'
                                           WHEN level = 3 THEN 'C'
                                           WHEN level = 4 THEN 'D'
                                           WHEN level = 5 THEN 'E'
                                           ELSE '-'
                                       END as level_text
                                FROM perf_assessments 
                                WHERE user_id = ?
                                ORDER BY year DESC, month DESC
                                LIMIT 5
                            ");
                            $stmt->execute([$_SESSION['user_id']]);
                            $assessments = $stmt->fetchAll();

                            if (empty($assessments)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无考核记录</td>
                                </tr>
                                <?php else:
                                foreach ($assessments as $assessment): ?>
                                    <tr>
                                        <td><?php echo $assessment['assessment_period']; ?></td>
                                        <td><?php echo number_format($assessment['target_amount'], 2); ?></td>
                                        <td><?php echo number_format($assessment['actual_amount'], 2); ?></td>
                                        <td><?php echo $assessment['target_clients']; ?></td>
                                        <td><?php echo $assessment['actual_clients']; ?></td>
                                        <td><?php echo $assessment['score'] ?? '-'; ?></td>
                                        <td>
                                            <?php
                                            echo $assessment['level_text'];
                                            if ($assessment['level'] == 1) {
                                                echo ' <span style="color: #28a745;">(优秀)</span>';
                                            } elseif ($assessment['level'] == 2) {
                                                echo ' <span style="color: #4CAF50;">(良好)</span>';
                                            }
                                            ?>
                                        </td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="7" class="text-center">获取考核记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近激励记录</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>年月</th>
                            <th>类型</th>
                            <th>金额</th>
                            <th>说明</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->prepare("
                                SELECT *, 
                                       CONCAT(year, '年', month, '月') as incentive_period,
                                       CASE 
                                           WHEN type = 1 THEN '提成'
                                           WHEN type = 2 THEN '奖金'
                                           ELSE '其他奖励'
                                       END as type_text,
                                       CASE 
                                           WHEN status = 1 THEN '待发放'
                                           ELSE '已发放'
                                       END as status_text
                                FROM perf_incentives 
                                WHERE user_id = ?
                                ORDER BY year DESC, month DESC
                                LIMIT 5
                            ");
                            $stmt->execute([$_SESSION['user_id']]);
                            $incentives = $stmt->fetchAll();

                            if (empty($incentives)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无激励记录</td>
                                </tr>
                                <?php else:
                                foreach ($incentives as $incentive): ?>
                                    <tr>
                                        <td><?php echo $incentive['incentive_period']; ?></td>
                                        <td><?php echo $incentive['type_text']; ?></td>
                                        <td><?php echo number_format($incentive['amount'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($incentive['description']); ?></td>
                                        <td>
                                            <?php
                                            if ($incentive['status'] == 1) {
                                                echo '<span style="color: #ffc107;">待发放</span>';
                                            } else {
                                                echo '<span style="color: #28a745;">已发放</span>';
                                            }
                                            ?>
                                        </td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="5" class="text-center">获取激励记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <div class="info-box">
                <h3>绩效与激励说明</h3>
                <p>绩效管理系统帮助您：</p>
                <ul>
                    <li><strong>明确销售目标</strong>：清晰了解个人和团队的销售目标和业绩期望。</li>
                    <li><strong>跟踪业绩表现</strong>：实时查看自己的业绩完成情况和考核结果。</li>
                    <li><strong>了解激励措施</strong>：查看提成、奖金等激励记录，激发工作积极性。</li>
                    <li><strong>团队协作</strong>：与团队成员共同努力，实现团队业绩目标。</li>
                </ul>
                <p>提示：持续追踪您的绩效，及时调整工作策略，有助于提高销售业绩。</p>
            </div>
        </div>
    </div>
</body>

</html>