<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_marketing');

// 记录访问日志
record_log('访问市场营销分析页面');

// 获取分析数据的时间范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-6 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $report_type = isset($_POST['report_type']) ? intval($_POST['report_type']) : 1;

        if (empty($title) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的报表信息！';
        } else {
            try {
                // 获取市场营销分析模板
                $stmt = $pdo->prepare("SELECT id FROM report_templates WHERE category = 3 AND name LIKE '%营销活动%' LIMIT 1");
                $stmt->execute();
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到市场营销分析模板！';
                } else {
                    // 构建查询参数
                    $params = json_encode([
                        'start_date' => $start_date,
                        'end_date' => $end_date,
                        'report_type' => $report_type
                    ]);

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '市场营销分析_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径 - 修改为使用相对于网站根目录的路径
                    $web_file_path = 'report/reports/' . $file_name; // 关键修改：添加report/前缀

                    // 根据报表类型获取相应的数据
                    if ($report_type == 1 || $report_type == 3) {
                        // 获取月度营销效果趋势
                        $stmt = $pdo->prepare("
                            SELECT 
                                DATE_FORMAT(c.start_date, '%Y-%m') as month, 
                                SUM(r.conversion) as conversions,
                                SUM(r.cost) as total_cost,
                                SUM(r.revenue) as total_revenue,
                                CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi
                            FROM mkt_campaigns c
                            LEFT JOIN mkt_results r ON c.id = r.campaign_id
                            WHERE c.start_date BETWEEN ? AND ? 
                            GROUP BY month 
                            ORDER BY month
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $monthly_data = $stmt->fetchAll();
                    }

                    if ($report_type == 1 || $report_type == 2) {
                        // 获取活动效果排名
                        $stmt = $pdo->prepare("
                            SELECT 
                                c.name as campaign_name,
                                c.type as campaign_type,
                                SUM(r.reach) as reach,
                                SUM(r.click) as clicks,
                                SUM(r.conversion) as conversions,
                                SUM(r.cost) as cost,
                                SUM(r.revenue) as revenue,
                                CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi,
                                CASE WHEN SUM(r.reach) > 0 THEN ROUND((SUM(r.conversion) / SUM(r.reach)) * 100, 2) ELSE 0 END as conversion_rate
                            FROM mkt_campaigns c
                            LEFT JOIN mkt_results r ON c.id = r.campaign_id
                            WHERE c.start_date BETWEEN ? AND ? 
                            GROUP BY c.id
                            ORDER BY roi DESC
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $campaign_data = $stmt->fetchAll();

                        // 获取渠道效果分析
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN ch.type = 1 THEN '邮件'
                                    WHEN ch.type = 2 THEN '短信'
                                    WHEN ch.type = 3 THEN '社交媒体'
                                    WHEN ch.type = 4 THEN '搜索引擎'
                                    ELSE '其他'
                                END as channel_type,
                                SUM(r.reach) as reach,
                                SUM(r.click) as clicks,
                                SUM(r.conversion) as conversions,
                                SUM(r.cost) as cost,
                                SUM(r.revenue) as revenue,
                                CASE WHEN SUM(r.reach) > 0 THEN ROUND((SUM(r.click) / SUM(r.reach)) * 100, 2) ELSE 0 END as click_rate,
                                CASE WHEN SUM(r.click) > 0 THEN ROUND((SUM(r.conversion) / SUM(r.click)) * 100, 2) ELSE 0 END as conversion_rate,
                                CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi
                            FROM mkt_channels ch
                            JOIN mkt_campaigns c ON ch.campaign_id = c.id
                            LEFT JOIN mkt_results r ON ch.id = r.channel_id
                            WHERE c.start_date BETWEEN ? AND ? 
                            GROUP BY ch.type
                            ORDER BY roi DESC
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $channel_data = $stmt->fetchAll();

                        // 获取活动类型分布
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN type = 1 THEN '线上活动'
                                    WHEN type = 2 THEN '线下活动'
                                    WHEN type = 3 THEN '联合营销'
                                    ELSE '其他'
                                END as type_name,
                                COUNT(*) as count,
                                SUM(budget) as total_budget
                            FROM mkt_campaigns 
                            WHERE start_date BETWEEN ? AND ? 
                            GROUP BY type
                            ORDER BY type
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $campaign_type_data = $stmt->fetchAll();
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    fputcsv($file, []);  // 空行

                    // 写入月度趋势数据
                    if ($report_type == 1 || $report_type == 3) {
                        fputcsv($file, ['月度营销效果趋势']);
                        fputcsv($file, ['月份', '转化数', '营销成本', '营销收入', 'ROI(%)']);
                        foreach ($monthly_data as $row) {
                            fputcsv($file, [
                                $row['month'],
                                $row['conversions'],
                                $row['total_cost'],
                                $row['total_revenue'],
                                $row['roi']
                            ]);
                        }
                        fputcsv($file, []);  // 空行
                    }

                    // 写入活动效果排名
                    if ($report_type == 1 || $report_type == 2) {
                        fputcsv($file, ['活动效果排名']);
                        fputcsv($file, ['活动名称', '活动类型', '触达人数', '点击数', '转化数', '成本', '收入', 'ROI(%)', '转化率(%)']);
                        foreach ($campaign_data as $campaign) {
                            $campaign_type = '';
                            switch ($campaign['campaign_type']) {
                                case 1:
                                    $campaign_type = '线上活动';
                                    break;
                                case 2:
                                    $campaign_type = '线下活动';
                                    break;
                                case 3:
                                    $campaign_type = '联合营销';
                                    break;
                                default:
                                    $campaign_type = '其他';
                            }

                            fputcsv($file, [
                                $campaign['campaign_name'],
                                $campaign_type,
                                $campaign['reach'],
                                $campaign['clicks'],
                                $campaign['conversions'],
                                $campaign['cost'],
                                $campaign['revenue'],
                                $campaign['roi'],
                                $campaign['conversion_rate']
                            ]);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入渠道效果分析
                        fputcsv($file, ['渠道效果分析']);
                        fputcsv($file, ['渠道类型', '触达人数', '点击数', '转化数', '成本', '收入', '点击率(%)', '转化率(%)', 'ROI(%)']);
                        foreach ($channel_data as $channel) {
                            fputcsv($file, [
                                $channel['channel_type'],
                                $channel['reach'],
                                $channel['clicks'],
                                $channel['conversions'],
                                $channel['cost'],
                                $channel['revenue'],
                                $channel['click_rate'],
                                $channel['conversion_rate'],
                                $channel['roi']
                            ]);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入活动类型分布
                        fputcsv($file, ['活动类型分布']);
                        fputcsv($file, ['活动类型', '数量', '总预算', '占比']);
                        $total = 0;
                        $total_budget = 0;
                        foreach ($campaign_type_data as $type) {
                            $total += $type['count'];
                            $total_budget += $type['total_budget'];
                        }
                        foreach ($campaign_type_data as $type) {
                            $percentage = $total > 0 ? round(($type['count'] / $total) * 100, 2) : 0;
                            fputcsv($file, [
                                $type['type_name'],
                                $type['count'],
                                $type['total_budget'],
                                $percentage . '%'
                            ]);
                        }
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template['id'], $title, $params, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成市场营销分析报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取月度营销效果趋势
try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(c.start_date, '%Y-%m') as month, 
            SUM(r.conversion) as conversions,
            SUM(r.cost) as total_cost,
            SUM(r.revenue) as total_revenue,
            CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi
        FROM mkt_campaigns c
        LEFT JOIN mkt_results r ON c.id = r.campaign_id
        WHERE c.start_date BETWEEN ? AND ? 
        GROUP BY month 
        ORDER BY month
    ");
    $stmt->execute([$start_date, $end_date]);
    $monthly_trends = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取月度营销效果趋势数据失败：' . $e->getMessage();
    $monthly_trends = [];
}

// 获取活动效果排名
try {
    $stmt = $pdo->prepare("
        SELECT 
            c.name as campaign_name,
            c.type as campaign_type,
            SUM(r.reach) as reach,
            SUM(r.click) as clicks,
            SUM(r.conversion) as conversions,
            SUM(r.cost) as cost,
            SUM(r.revenue) as revenue,
            CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi,
            CASE WHEN SUM(r.reach) > 0 THEN ROUND((SUM(r.conversion) / SUM(r.reach)) * 100, 2) ELSE 0 END as conversion_rate
        FROM mkt_campaigns c
        LEFT JOIN mkt_results r ON c.id = r.campaign_id
        WHERE c.start_date BETWEEN ? AND ? 
        GROUP BY c.id
        ORDER BY roi DESC
    ");
    $stmt->execute([$start_date, $end_date]);
    $campaign_ranking = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活动效果排名数据失败：' . $e->getMessage();
    $campaign_ranking = [];
}

// 获取渠道效果分析
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN ch.type = 1 THEN '邮件'
                WHEN ch.type = 2 THEN '短信'
                WHEN ch.type = 3 THEN '社交媒体'
                WHEN ch.type = 4 THEN '搜索引擎'
                ELSE '其他'
            END as channel_type,
            SUM(r.reach) as reach,
            SUM(r.click) as clicks,
            SUM(r.conversion) as conversions,
            SUM(r.cost) as cost,
            SUM(r.revenue) as revenue,
            CASE WHEN SUM(r.reach) > 0 THEN ROUND((SUM(r.click) / SUM(r.reach)) * 100, 2) ELSE 0 END as click_rate,
            CASE WHEN SUM(r.click) > 0 THEN ROUND((SUM(r.conversion) / SUM(r.click)) * 100, 2) ELSE 0 END as conversion_rate,
            CASE WHEN SUM(r.cost) > 0 THEN ROUND((SUM(r.revenue) / SUM(r.cost)) * 100, 2) ELSE 0 END as roi
        FROM mkt_channels ch
        JOIN mkt_campaigns c ON ch.campaign_id = c.id
        LEFT JOIN mkt_results r ON ch.id = r.channel_id
        WHERE c.start_date BETWEEN ? AND ? 
        GROUP BY ch.type
        ORDER BY roi DESC
    ");
    $stmt->execute([$start_date, $end_date]);
    $channel_analysis = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取渠道效果分析数据失败：' . $e->getMessage();
    $channel_analysis = [];
}

// 获取活动类型分布
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN type = 1 THEN '线上活动'
                WHEN type = 2 THEN '线下活动'
                WHEN type = 3 THEN '联合营销'
                ELSE '其他'
            END as type_name,
            COUNT(*) as count,
            SUM(budget) as total_budget
        FROM mkt_campaigns 
        WHERE start_date BETWEEN ? AND ? 
        GROUP BY type
        ORDER BY type
    ");
    $stmt->execute([$start_date, $end_date]);
    $campaign_type_distribution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活动类型分布数据失败：' . $e->getMessage();
    $campaign_type_distribution = [];
}

// 获取最近生成的市场营销分析报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        WHERE t.category = 3 AND t.name LIKE '%营销活动%'
        ORDER BY r.create_time DESC
        LIMIT 5
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 计算统计数据
$total_conversions = 0;
$total_cost = 0;
$total_revenue = 0;
foreach ($monthly_trends as $month) {
    $total_conversions += $month['conversions'];
    $total_cost += $month['total_cost'];
    $total_revenue += $month['total_revenue'];
}

// 计算平均转化率
$total_reach = 0;
foreach ($campaign_ranking as $campaign) {
    $total_reach += $campaign['reach'];
}
$avg_conversion_rate = $total_reach > 0 ? round(($total_conversions / $total_reach) * 100, 2) : 0;

// 计算总体ROI
$overall_roi = $total_cost > 0 ? round(($total_revenue / $total_cost) * 100, 2) : 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>市场营销分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 市场营销分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">查询</button>
                    </div>
                </form>
            </div>

            <!-- 统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总转化数</h3>
                    <div class="number"><?php echo $total_conversions; ?></div>
                    <div class="desc">所选时间范围内总转化数</div>
                </div>

                <div class="dashboard-card">
                    <h3>平均转化率</h3>
                    <div class="number"><?php echo $avg_conversion_rate; ?>%</div>
                    <div class="desc">转化数/触达人数的百分比</div>
                </div>

                <div class="dashboard-card">
                    <h3>总体ROI</h3>
                    <div class="number"><?php echo $overall_roi; ?>%</div>
                    <div class="desc">投资回报率：收入/成本的百分比</div>
                </div>
            </div>

            <!-- 月度营销效果趋势 -->
            <div class="section">
                <h3>月度营销效果趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>转化数</th>
                            <th>营销成本</th>
                            <th>营销收入</th>
                            <th>ROI(%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_trends)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($monthly_trends as $month): ?>
                                <tr>
                                    <td><?php echo $month['month']; ?></td>
                                    <td><?php echo $month['conversions']; ?></td>
                                    <td><?php echo number_format($month['total_cost'], 2); ?></td>
                                    <td><?php echo number_format($month['total_revenue'], 2); ?></td>
                                    <td><?php echo $month['roi']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 活动效果排名 -->
            <div class="section">
                <h3>活动效果排名</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>触达人数</th>
                            <th>转化数</th>
                            <th>转化率(%)</th>
                            <th>ROI(%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($campaign_ranking)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($campaign_ranking as $campaign): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($campaign['campaign_name']); ?></td>
                                    <td>
                                        <?php
                                        switch ($campaign['campaign_type']) {
                                            case 1:
                                                echo '线上活动';
                                                break;
                                            case 2:
                                                echo '线下活动';
                                                break;
                                            case 3:
                                                echo '联合营销';
                                                break;
                                            default:
                                                echo '其他';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $campaign['reach']; ?></td>
                                    <td><?php echo $campaign['conversions']; ?></td>
                                    <td><?php echo $campaign['conversion_rate']; ?>%</td>
                                    <td><?php echo $campaign['roi']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 渠道效果分析 -->
            <div class="section">
                <h3>渠道效果分析</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>渠道类型</th>
                            <th>触达人数</th>
                            <th>点击数</th>
                            <th>点击率(%)</th>
                            <th>转化数</th>
                            <th>转化率(%)</th>
                            <th>ROI(%)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($channel_analysis)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($channel_analysis as $channel): ?>
                                <tr>
                                    <td><?php echo $channel['channel_type']; ?></td>
                                    <td><?php echo $channel['reach']; ?></td>
                                    <td><?php echo $channel['clicks']; ?></td>
                                    <td><?php echo $channel['click_rate']; ?>%</td>
                                    <td><?php echo $channel['conversions']; ?></td>
                                    <td><?php echo $channel['conversion_rate']; ?>%</td>
                                    <td><?php echo $channel['roi']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 活动类型分布 -->
            <div class="section">
                <h3>活动类型分布</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>活动类型</th>
                            <th>数量</th>
                            <th>总预算</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($campaign_type_distribution)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php
                            $total = 0;
                            foreach ($campaign_type_distribution as $type) {
                                $total += $type['count'];
                            }
                            foreach ($campaign_type_distribution as $type):
                                $percentage = $total > 0 ? round(($type['count'] / $total) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo $type['type_name']; ?></td>
                                    <td><?php echo $type['count']; ?></td>
                                    <td><?php echo number_format($type['total_budget'], 2); ?></td>
                                    <td><?php echo $percentage; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成报表</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="generate">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="市场营销分析报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_start_date">统计开始日期：</label>
                        <input type="date" id="report_start_date" name="start_date" value="<?php echo $start_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_end_date">统计结束日期：</label>
                        <input type="date" id="report_end_date" name="end_date" value="<?php echo $end_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型：</label>
                        <select id="report_type" name="report_type">
                            <option value="1">完整报表（包含所有数据）</option>
                            <option value="2">效果报表（侧重活动和渠道效果）</option>
                            <option value="3">趋势报表（侧重月度趋势）</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>历史报表记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于市场营销分析</h3>
                <p>市场营销分析帮助您了解：</p>
                <ul>
                    <li><strong>营销效果</strong>：评估不同活动的转化率和投资回报率(ROI)。</li>
                    <li><strong>渠道表现</strong>：分析各营销渠道的效果，优化资源分配。</li>
                    <li><strong>趋势变化</strong>：监控营销效果的月度变化，识别趋势。</li>
                    <li><strong>预算分配</strong>：评估不同类型活动的预算使用情况。</li>
                </ul>
                <p>定期分析市场营销数据，可以帮助您优化营销策略，提高营销投资回报。</p>
            </div>
        </div>
    </div>
</body>

</html>