<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service_follow');

// 记录访问日志
record_log('访问售后跟进管理页面');

// 添加/编辑/处理售后记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加售后记录
    if ($_POST['action'] == 'add') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($order_id <= 0 || empty($reason)) {
            $error = '请填写完整的售后信息！';
        } else {
            try {
                // 检查订单是否存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $result = $stmt->fetch();

                if ($result['count'] == 0) {
                    $error = '所选订单不存在！';
                } else {
                    // 添加售后记录
                    $stmt = $pdo->prepare("INSERT INTO service_aftersales (order_id, type, reason, status) VALUES (?, ?, ?, ?)");
                    $result = $stmt->execute([$order_id, $type, $reason, $status]);

                    if ($result) {
                        record_log("添加售后记录，订单ID：{$order_id}，类型：" . ($type == 1 ? '维修' : ($type == 2 ? '换货' : '退货')));
                        $success = '售后记录添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: follow.php?success=add');
                        exit;
                    } else {
                        $error = '售后记录添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新售后记录状态
    elseif ($_POST['action'] == 'update_status') {
        $aftersale_id = isset($_POST['aftersale_id']) ? intval($_POST['aftersale_id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($aftersale_id <= 0) {
            $error = '无效的售后记录ID！';
        } else {
            try {
                // 更新售后记录状态
                $stmt = $pdo->prepare("UPDATE service_aftersales SET status = ? WHERE id = ?");
                $result = $stmt->execute([$status, $aftersale_id]);

                if ($result) {
                    $status_text = $status == 2 ? '已处理' : '申请中';
                    record_log("更新售后记录ID：{$aftersale_id} 状态为：{$status_text}");
                    $success = '售后记录状态更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: follow.php?success=update');
                    exit;
                } else {
                    $error = '售后记录状态更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除售后记录
    elseif ($_POST['action'] == 'delete') {
        $aftersale_id = isset($_POST['aftersale_id']) ? intval($_POST['aftersale_id']) : 0;

        if ($aftersale_id <= 0) {
            $error = '无效的售后记录ID！';
        } else {
            try {
                // 删除售后记录
                $stmt = $pdo->prepare("DELETE FROM service_aftersales WHERE id = ?");
                $result = $stmt->execute([$aftersale_id]);

                if ($result) {
                    record_log("删除售后记录ID：{$aftersale_id}");
                    $success = '售后记录删除成功！';
                } else {
                    $error = '售后记录删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选参数
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : -1;
$type_filter = isset($_GET['type']) ? intval($_GET['type']) : 0;

// 构建筛选条件
$where_conditions = [];
$params = [];

if ($status_filter >= 0) {
    $where_conditions[] = "a.status = ?";
    $params[] = $status_filter;
}

if ($type_filter > 0) {
    $where_conditions[] = "a.type = ?";
    $params[] = $type_filter;
}

$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 获取所有售后记录
try {
    $sql = "SELECT a.*, o.order_no, c.client_name 
            FROM service_aftersales a
            JOIN order_orders o ON a.order_id = o.id
            JOIN crm_clients c ON o.client_id = c.id
            {$where_clause}
            ORDER BY a.create_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $aftersales = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取售后记录列表失败：' . $e->getMessage();
    $aftersales = [];
}

// 获取所有订单，用于添加售后记录
try {
    $stmt = $pdo->query("SELECT o.id, o.order_no, c.client_name 
                        FROM order_orders o
                        JOIN crm_clients c ON o.client_id = c.id
                        WHERE o.status >= 2 /* 已支付及以上状态 */
                        ORDER BY o.create_time DESC");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
    $orders = [];
}

// 判断是否显示表单
$show_form = false;

// 添加售后记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '售后记录添加成功！';
    } elseif ($_GET['success'] == 'update') {
        $success = '售后记录状态更新成功！';
    }
}

// 统计各种状态和类型的售后记录数量
$pending_count = 0;
$processed_count = 0;
$repair_count = 0;
$exchange_count = 0;
$return_count = 0;

foreach ($aftersales as $aftersale) {
    if ($aftersale['status'] == 1) {
        $pending_count++;
    } else {
        $processed_count++;
    }

    if ($aftersale['type'] == 1) {
        $repair_count++;
    } elseif ($aftersale['type'] == 2) {
        $exchange_count++;
    } else {
        $return_count++;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>售后跟进管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户服务与售后</a> &gt; 售后跟进管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 售后统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>待处理</h3>
                    <div class="number"><?php echo $pending_count; ?></div>
                    <div class="desc"><a href="?status=1">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>已处理</h3>
                    <div class="number"><?php echo $processed_count; ?></div>
                    <div class="desc"><a href="?status=2">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>维修</h3>
                    <div class="number"><?php echo $repair_count; ?></div>
                    <div class="desc"><a href="?type=1">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>换货</h3>
                    <div class="number"><?php echo $exchange_count; ?></div>
                    <div class="desc"><a href="?type=2">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>退货</h3>
                    <div class="number"><?php echo $return_count; ?></div>
                    <div class="desc"><a href="?type=3">查看详情</a></div>
                </div>
            </div>

            <div class="action-bar">
                <a href="follow.php?action=add" class="btn btn-add">添加售后记录</a>
                <a href="follow.php" class="btn btn-secondary">全部记录</a>
            </div>

            <!-- 添加售后记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3>添加售后记录</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="order_id">选择订单：</label>
                            <select id="order_id" name="order_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($orders as $order): ?>
                                    <option value="<?php echo $order['id']; ?>"><?php echo htmlspecialchars($order['order_no'] . ' - ' . $order['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">售后类型：</label>
                            <select id="type" name="type">
                                <option value="1">维修</option>
                                <option value="2">换货</option>
                                <option value="3">退货</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="reason">售后原因：</label>
                            <textarea id="reason" name="reason" rows="4" required></textarea>
                        </div>

                        <div class="form-group">
                            <label for="status">处理状态：</label>
                            <select id="status" name="status">
                                <option value="1">申请中</option>
                                <option value="2">已处理</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">提交记录</button>
                            <a href="follow.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 售后记录筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">处理状态：</label>
                            <select id="status" name="status" onchange="this.form.submit()">
                                <option value="-1">全部</option>
                                <option value="1" <?php echo $status_filter === 1 ? 'selected' : ''; ?>>申请中</option>
                                <option value="2" <?php echo $status_filter === 2 ? 'selected' : ''; ?>>已处理</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="type">售后类型：</label>
                            <select id="type" name="type" onchange="this.form.submit()">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $type_filter == 1 ? 'selected' : ''; ?>>维修</option>
                                <option value="2" <?php echo $type_filter == 2 ? 'selected' : ''; ?>>换货</option>
                                <option value="3" <?php echo $type_filter == 3 ? 'selected' : ''; ?>>退货</option>
                            </select>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 售后记录列表 -->
            <div class="table-container">
                <h3>售后记录列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>订单编号</th>
                            <th>客户</th>
                            <th>类型</th>
                            <th>原因</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($aftersales)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无售后记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($aftersales as $aftersale): ?>
                                <tr>
                                    <td><?php echo $aftersale['id']; ?></td>
                                    <td><?php echo htmlspecialchars($aftersale['order_no']); ?></td>
                                    <td><?php echo htmlspecialchars($aftersale['client_name']); ?></td>
                                    <td>
                                        <?php
                                        if ($aftersale['type'] == 1) echo '维修';
                                        elseif ($aftersale['type'] == 2) echo '换货';
                                        elseif ($aftersale['type'] == 3) echo '退货';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($aftersale['reason']); ?></td>
                                    <td>
                                        <?php
                                        if ($aftersale['status'] == 1) echo '<span class="status-pending">申请中</span>';
                                        else echo '<span class="status-active">已处理</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($aftersale['create_time'])); ?></td>
                                    <td>
                                        <?php if ($aftersale['status'] == 1): ?>
                                            <form method="post" action="" style="display: inline;">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="aftersale_id" value="<?php echo $aftersale['id']; ?>">
                                                <input type="hidden" name="status" value="2">
                                                <button type="submit" class="btn btn-sm btn-success">标记为已处理</button>
                                            </form>
                                        <?php else: ?>
                                            <form method="post" action="" style="display: inline;">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="aftersale_id" value="<?php echo $aftersale['id']; ?>">
                                                <input type="hidden" name="status" value="1">
                                                <button type="submit" class="btn btn-sm btn-primary">标记为申请中</button>
                                            </form>
                                        <?php endif; ?>
                                        <form method="post" action="" style="display: inline;">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="aftersale_id" value="<?php echo $aftersale['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此售后记录吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 使用说明 -->
            <div class="info-box">
                <h3>售后跟进管理说明</h3>
                <ul>
                    <li>本页面用于管理产品或服务的售后跟进记录，包括维修、换货和退货。</li>
                    <li>您可以添加新的售后记录，选择相关订单并填写售后原因。</li>
                    <li>售后记录分为"申请中"和"已处理"两种状态，您可以根据处理情况更新状态。</li>
                    <li>售后类型包括维修、换货和退货三种，可根据实际情况选择。</li>
                    <li>您可以使用筛选功能查看不同状态和类型的售后记录。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>