-- 1、用户与权限管理
-- 用户表
CREATE TABLE `sys_users` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
    `username` varchar(50) NOT NULL COMMENT '用户名',
    `password` varchar(255) NOT NULL COMMENT '密码',
    `mobile` varchar(20) DEFAULT NULL COMMENT '手机号',
    `email` varchar(100) DEFAULT NULL COMMENT '邮箱',
    `role_id` int(11) NOT NULL DEFAULT 3 COMMENT '角色ID',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=启用，0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_username` (`username`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '系统用户表';

-- 角色权限表
CREATE TABLE `sys_roles` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
    `role_name` varchar(50) NOT NULL COMMENT '角色名称',
    `permissions` text DEFAULT NULL COMMENT '权限(JSON格式)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '角色权限表';

-- 操作日志表
CREATE TABLE `sys_logs` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '日志ID',
    `user_id` int(11) DEFAULT NULL COMMENT '操作用户ID',
    `username` varchar(50) DEFAULT NULL COMMENT '操作用户名',
    `operation` varchar(500) NOT NULL COMMENT '操作描述',
    `ip` varchar(50) DEFAULT NULL COMMENT '操作IP',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '操作日志表';

-- 数据备份表
CREATE TABLE `sys_backups` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '备份ID',
    `backup_name` varchar(100) NOT NULL COMMENT '备份名称',
    `backup_path` varchar(255) NOT NULL COMMENT '备份文件路径',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '数据备份表';

-- 初始化角色数据
INSERT INTO
    `sys_roles` (`id`, `role_name`, `permissions`)
VALUES
    (
        1,
        '系统管理员',
        '{"all": true, "system": true, "user": true, "role": true, "backup": true, "client": true, "contact": true, "sales": true, "contract": true, "order": true, "marketing": true, "service": true, "product": true, "finance": true, "report": true, "task": true, "performance": true}'
    ),
    (
        2,
        '销售人员',
        '{"client": true, "contact": true, "sales": true, "contract": {"view": true, "add": true, "edit": true}, "order": {"view": true, "add": true}, "product": {"view": true}, "task": true, "profile": true, "report": {"view": true}}'
    ),
    (
        3,
        '客服',
        '{"client": {"view": true}, "service": true, "order": {"view": true}, "task": true, "profile": true}'
    ),
    (
        4,
        '市场专员',
        '{"marketing": true, "client": {"view": true}, "contact": {"view": true}, "report": {"view": true, "marketing": true}, "task": true, "profile": true}'
    );

-- 初始管理员账户，密码为admin的MD5哈希值
INSERT INTO
    `sys_users` (
        `username`,
        `password`,
        `mobile`,
        `email`,
        `role_id`,
        `status`
    )
VALUES
    (
        'admin',
        '21232f297a57a5a743894a0e4a801fc3',
        '13800138000',
        'admin@smartcrm.com',
        1,
        1
    );

-- 2、客户管理
-- 客户表
CREATE TABLE `crm_clients` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '客户ID',
    `client_name` varchar(100) NOT NULL COMMENT '客户名称',
    `client_type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '客户类型：1=企业,2=个人',
    `client_level` tinyint(1) NOT NULL DEFAULT '2' COMMENT '客户级别：1=VIP,2=普通,3=潜在',
    `industry` varchar(50) DEFAULT NULL COMMENT '行业',
    `address` varchar(255) DEFAULT NULL COMMENT '地址',
    `owner_user_id` int(11) DEFAULT NULL COMMENT '负责人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_owner_user_id` (`owner_user_id`),
    CONSTRAINT `fk_client_owner` FOREIGN KEY (`owner_user_id`) REFERENCES `sys_users` (`id`) ON DELETE SET NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '客户表';

-- 联系人表
CREATE TABLE `crm_contacts` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '联系人ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `name` varchar(50) NOT NULL COMMENT '姓名',
    `position` varchar(50) DEFAULT NULL COMMENT '职位',
    `mobile` varchar(20) DEFAULT NULL COMMENT '手机',
    `email` varchar(100) DEFAULT NULL COMMENT '邮箱',
    `is_primary` tinyint(1) NOT NULL DEFAULT '0' COMMENT '主要联系人：1=是,0=否',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_client_id` (`client_id`),
    CONSTRAINT `fk_contact_client` FOREIGN KEY (`client_id`) REFERENCES `crm_clients` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '联系人表';

ALTER TABLE crm_contacts ADD COLUMN birthday DATE DEFAULT NULL COMMENT '生日' AFTER email;

-- 客户互动表
CREATE TABLE `crm_interactions` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '互动ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `user_id` int(11) NOT NULL COMMENT '员工ID',
    `type` varchar(20) NOT NULL COMMENT '类型：电话/邮件/会议/拜访',
    `subject` varchar(100) NOT NULL COMMENT '主题',
    `interaction_time` datetime NOT NULL COMMENT '互动时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_client_id` (`client_id`),
    CONSTRAINT `fk_interaction_client` FOREIGN KEY (`client_id`) REFERENCES `crm_clients` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '客户互动表';

ALTER TABLE `crm_interactions` 
ADD COLUMN `content` text DEFAULT NULL COMMENT '互动内容' 
AFTER `subject`;

-- 初始化客户示例数据
INSERT INTO `crm_clients` (`client_name`, `client_type`, `client_level`, `industry`, `address`, `owner_user_id`) VALUES ('腾讯科技有限公司', 1, 1, '互联网', '深圳市南山区腾讯大厦', 1), ('阿里巴巴集团', 1, 1, '电子商务', '杭州市余杭区阿里巴巴西溪园区', 1), ('张三', 2, 2, NULL, '上海市浦东新区', 1);

-- 初始化联系人示例数据
INSERT INTO `crm_contacts` (`client_id`, `name`, `position`, `mobile`, `email`, `birthday`, `is_primary`) VALUES (1, '马化腾', '首席执行官', '13900000001', 'pony.ma@example.com', '1971-10-29', 1), (1, '刘成城', 'CIO', '13900000002', 'liu.cc@example.com', '1980-01-01', 0), (2, '马云', '创始人', '13900000003', 'jack.ma@example.com', '1964-10-15', 1), (3, '张三', '创业者', '13900000005', 'zhangsan@example.com', '1985-05-10', 1);

-- 初始化客户互动记录示例数据
INSERT INTO `crm_interactions` (`client_id`, `user_id`, `type`, `subject`, `interaction_time`) VALUES (1, 1, '会议', '系统需求沟通','2023-05-10 14:00:00'), (1, 1, '电话', '技术对接','2023-05-15 10:30:00'), (2, 1, '拜访', '需求调研', '2023-05-12 09:00:00'), (3, 1, '电话', '产品咨询', '2023-05-20 11:15:00');

-- 3、销售管理
-- 销售线索/机会表 (合并销售线索和机会功能)
CREATE TABLE `sales_leads` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `name` varchar(100) NOT NULL COMMENT '名称',
    `type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '类型：1=线索,2=机会',
    `source` varchar(50) DEFAULT NULL COMMENT '来源',
    `stage` tinyint(1) DEFAULT '1' COMMENT '阶段：1=新建,2=跟进中,3=报价,4=赢单,5=输单',
    `amount` decimal(12,2) DEFAULT NULL COMMENT '预计金额',
    `owner_user_id` int(11) DEFAULT NULL COMMENT '负责人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_client_id` (`client_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '销售线索/机会表';

-- 合同表
CREATE TABLE `sales_contracts` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `lead_id` int(11) DEFAULT NULL COMMENT '线索/机会ID',
    `contract_no` varchar(50) NOT NULL COMMENT '合同编号',
    `amount` decimal(12,2) NOT NULL COMMENT '金额',
    `start_date` date NOT NULL COMMENT '开始日期',
    `end_date` date NOT NULL COMMENT '结束日期',
    `status` tinyint(1) DEFAULT '1' COMMENT '状态：1=草稿,2=审核中,3=已生效',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_contract_no` (`contract_no`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '合同表';

-- 报价表
CREATE TABLE `sales_quotes` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `lead_id` int(11) DEFAULT NULL COMMENT '线索/机会ID',
    `quote_no` varchar(50) NOT NULL COMMENT '报价单号',
    `amount` decimal(12,2) NOT NULL COMMENT '金额',
    `status` tinyint(1) DEFAULT '1' COMMENT '状态：1=草稿,2=已发送,3=已接受',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_quote_no` (`quote_no`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '报价表';

-- 销售目标表
CREATE TABLE `sales_targets` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `user_id` int(11) NOT NULL COMMENT '用户ID',
    `year` int(4) NOT NULL COMMENT '年份',
    `month` int(2) NOT NULL COMMENT '月份',
    `target_amount` decimal(12,2) NOT NULL COMMENT '目标金额',
    `actual_amount` decimal(12,2) DEFAULT '0.00' COMMENT '实际金额',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_user_month` (`user_id`,`year`,`month`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '销售目标表';

-- 初始化示例数据
INSERT INTO `sales_leads` (`client_id`, `name`, `type`, `source`, `stage`, `amount`, `owner_user_id`) VALUES (1, '腾讯CRM系统项目', 2, '展会', 3, 500000.00, 1), (2, '阿里销售模块', 2, '老客户推荐', 2, 300000.00, 1), (3, '张三个人CRM', 1, '线上咨询', 4, 5000.00, 1);

INSERT INTO `sales_contracts` (`client_id`, `lead_id`, `contract_no`, `amount`, `start_date`, `end_date`, `status`) VALUES (3, 3, 'HT-2023001', 5000.00, '2023-06-15', '2024-06-14', 3);

INSERT INTO `sales_quotes` (`client_id`, `lead_id`, `quote_no`, `amount`, `status`) VALUES (1, 1, 'BJ-2023001', 500000.00, 2), (2, 2, 'BJ-2023002', 300000.00, 1);

INSERT INTO `sales_targets` (`user_id`, `year`, `month`, `target_amount`, `actual_amount`) VALUES (1, 2025, 3, 500000.00, 5000.00), (1, 2025, 4, 600000.00, 0.00);

-- 4、订单管理
-- 订单表
CREATE TABLE `order_orders` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单ID',
    `order_no` varchar(50) NOT NULL COMMENT '订单编号',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `contract_id` int(11) DEFAULT NULL COMMENT '关联合同ID',
    `amount` decimal(12,2) NOT NULL COMMENT '订单金额',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=待支付,2=已支付,3=已发货,4=已完成,5=已取消',
    `payment_method` varchar(50) DEFAULT NULL COMMENT '支付方式',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `creator_id` int(11) NOT NULL COMMENT '创建人ID',
    `approver_id` int(11) DEFAULT NULL COMMENT '审核人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_order_no` (`order_no`),
    KEY `idx_client_id` (`client_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '订单表';

-- 发票表
CREATE TABLE `order_invoices` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '发票ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `invoice_no` varchar(50) DEFAULT NULL COMMENT '发票号码',
    `invoice_type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '发票类型：1=普通,2=增值税',
    `amount` decimal(12,2) NOT NULL COMMENT '发票金额',
    `title` varchar(100) NOT NULL COMMENT '发票抬头',
    `tax_no` varchar(50) DEFAULT NULL COMMENT '税号',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=申请中,2=已开票,3=已寄出,4=已取消',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_order_id` (`order_id`),
    CONSTRAINT `fk_invoice_order` FOREIGN KEY (`order_id`) REFERENCES `order_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '发票表';

ALTER TABLE `order_invoices` ADD COLUMN `remark` varchar(255) DEFAULT NULL COMMENT '备注' AFTER `tax_no`;

-- 退款表
CREATE TABLE `order_refunds` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '退款ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `refund_no` varchar(50) NOT NULL COMMENT '退款编号',
    `amount` decimal(12,2) NOT NULL COMMENT '退款金额',
    `type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '类型：1=退款,2=退货退款',
    `reason` varchar(255) DEFAULT NULL COMMENT '原因',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=申请中,2=审核中,3=已批准,4=已拒绝',
    `approver_id` int(11) DEFAULT NULL COMMENT '审批人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_refund_no` (`refund_no`),
    KEY `idx_order_id` (`order_id`),
    CONSTRAINT `fk_refund_order` FOREIGN KEY (`order_id`) REFERENCES `order_orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '退款表';

-- 初始化订单示例数据
INSERT INTO `order_orders` (`order_no`, `client_id`, `contract_id`, `amount`, `status`, `payment_method`, `creator_id`) VALUES ('DD-20230001', 3, 1, 5000.00, 2, '银行转账', 1), ('DD-20230002', 1, NULL, 200000.00, 1, '待定', 1);

-- 初始化发票示例数据
INSERT INTO `order_invoices` (`order_id`, `invoice_no`, `invoice_type`, `amount`, `title`, `tax_no`, `status`) VALUES (1, 'FP-20230001', 1, 5000.00, '张三', NULL, 2);

-- 初始化退款示例数据
INSERT INTO `order_refunds` (`order_id`, `refund_no`, `amount`, `type`, `reason`, `status`) VALUES (1, 'TK-20230001', 1000.00, 1, '服务调整', 3);

-- 5、市场营销管理
-- 营销活动表
CREATE TABLE `mkt_campaigns` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '活动ID',
    `name` varchar(100) NOT NULL COMMENT '活动名称',
    `type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '类型：1=线上活动,2=线下活动,3=联合营销',
    `budget` decimal(12,2) DEFAULT NULL COMMENT '预算',
    `start_date` date NOT NULL COMMENT '开始日期',
    `end_date` date NOT NULL COMMENT '结束日期',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=计划中,2=执行中,3=已结束,4=已取消',
    `description` varchar(255) DEFAULT NULL COMMENT '描述',
    `target_audience` varchar(255) DEFAULT NULL COMMENT '目标受众',
    `owner_user_id` int(11) NOT NULL COMMENT '负责人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销活动表';

-- 营销渠道表
CREATE TABLE `mkt_channels` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '渠道ID',
    `campaign_id` int(11) NOT NULL COMMENT '活动ID',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=邮件,2=短信,3=社交媒体,4=搜索引擎',
    `name` varchar(100) NOT NULL COMMENT '渠道名称',
    `content` text DEFAULT NULL COMMENT '内容或模板',
    `send_time` datetime DEFAULT NULL COMMENT '发送时间',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=准备中,2=已发送,3=已完成',
    `target_count` int(11) DEFAULT NULL COMMENT '目标数量',
    `actual_count` int(11) DEFAULT '0' COMMENT '实际数量',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_campaign_id` (`campaign_id`),
    CONSTRAINT `fk_channel_campaign` FOREIGN KEY (`campaign_id`) REFERENCES `mkt_campaigns` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销渠道表';

-- 营销效果表
CREATE TABLE `mkt_results` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '结果ID',
    `campaign_id` int(11) NOT NULL COMMENT '活动ID',
    `channel_id` int(11) DEFAULT NULL COMMENT '渠道ID',
    `reach` int(11) DEFAULT '0' COMMENT '触达人数',
    `click` int(11) DEFAULT '0' COMMENT '点击次数',
    `conversion` int(11) DEFAULT '0' COMMENT '转化次数',
    `cost` decimal(12,2) DEFAULT '0.00' COMMENT '花费',
    `revenue` decimal(12,2) DEFAULT '0.00' COMMENT '收入',
    `roi` decimal(8,2) DEFAULT NULL COMMENT '投资回报率(%)',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_campaign_channel` (`campaign_id`,`channel_id`),
    CONSTRAINT `fk_result_campaign` FOREIGN KEY (`campaign_id`) REFERENCES `mkt_campaigns` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销效果表';

-- 初始化营销活动示例数据
INSERT INTO `mkt_campaigns` (`name`, `type`, `budget`, `start_date`, `end_date`, `status`, `target_audience`, `owner_user_id`) VALUES ('2023年夏季促销活动', 1, 50000.00, '2023-06-01', '2023-07-15', 2, '30-45岁专业人士', 1), ('产品发布会', 2, 100000.00, '2023-08-10', '2023-08-10', 1, '企业IT决策者', 1);

-- 初始化营销渠道示例数据
INSERT INTO `mkt_channels` (`campaign_id`, `type`, `name`, `content`, `send_time`, `status`, `target_count`, `actual_count`) VALUES (1, 1, '促销邮件', '尊敬的客户，我们的夏季促销活动开始了...', '2023-06-01 09:00:00', 2, 5000, 4850), (1, 2, '促销短信', '【SmartCRM】夏季促销开始，回复TD退订', '2023-06-02 10:00:00', 2, 10000, 9800), (2, 3, '产品发布社交媒体宣传', '全新SmartCRM即将发布，敬请期待...', NULL, 1, 50000, 0);

-- 初始化营销效果示例数据
INSERT INTO `mkt_results` (`campaign_id`, `channel_id`, `reach`, `click`, `conversion`, `cost`, `revenue`, `roi`) VALUES (1, 1, 4850, 1200, 80, 10000.00, 40000.00, 300.00), (1, 2, 9800, 2500, 120, 15000.00, 60000.00, 300.00);

-- 6、客户服务与售后
-- 工单表
CREATE TABLE `service_tickets` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '工单ID',
    `ticket_no` varchar(50) NOT NULL COMMENT '工单编号',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `title` varchar(100) NOT NULL COMMENT '标题',
    `type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '类型：1=咨询,2=投诉,3=故障,4=建议',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=待处理,2=处理中,3=已完成',
    `handler_id` int(11) DEFAULT NULL COMMENT '处理人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_ticket_no` (`ticket_no`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '工单表';

-- 客户反馈表
CREATE TABLE `service_feedback` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '反馈ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `type` tinyint(1) NOT NULL DEFAULT '1' COMMENT '类型：1=产品,2=服务,3=其他',
    `content` varchar(255) NOT NULL COMMENT '反馈内容',
    `status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '状态：0=未处理,1=已处理',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '客户反馈表';

-- 知识库表
CREATE TABLE `service_knowledge` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '知识ID',
    `title` varchar(100) NOT NULL COMMENT '标题',
    `content` text NOT NULL COMMENT '内容',
    `category` tinyint(1) NOT NULL DEFAULT '1' COMMENT '分类：1=常见问题,2=教程,3=故障排除',
    `create_user_id` int(11) NOT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '知识库表';

-- 售后记录表
CREATE TABLE `service_aftersales` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '售后ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=维修,2=换货,3=退货',
    `reason` varchar(255) NOT NULL COMMENT '原因',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=申请中,2=已处理',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '售后记录表';

-- 满意度调查表
CREATE TABLE `service_satisfaction` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '调查ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `score` tinyint(1) NOT NULL COMMENT '评分：1-5分',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '满意度调查表';

ALTER TABLE `service_satisfaction` 
ADD COLUMN `comment` TEXT NULL COMMENT '评价内容';

-- 初始化工单示例数据
INSERT INTO `service_tickets` (`ticket_no`, `client_id`, `title`, `type`, `status`, `handler_id`) VALUES ('GD-2023001', 3, '系统使用问题', 1, 3, 1), ('GD-2023002', 1, '功能建议', 4, 2, 1);

-- 初始化客户反馈示例数据
INSERT INTO `service_feedback` (`client_id`, `type`, `content`, `status`) VALUES (2, 1, '建议增加移动端应用，方便外勤人员使用', 1);

-- 初始化知识库示例数据
INSERT INTO `service_knowledge` (`title`, `content`, `category`, `create_user_id`) VALUES ('如何重置密码', '1. 点击登录页面的忘记密码 2. 输入您的注册邮箱 3. 按照邮件提示操作', 1, 1), ('客户数据导入教程', '使用Excel模板导入客户数据的详细步骤...', 2, 1);

-- 初始化售后记录示例数据
INSERT INTO `service_aftersales` (`order_id`, `type`, `reason`, `status`) VALUES (1, 1, '系统功能异常，无法正常使用报表功能', 2);

-- 初始化满意度调查示例数据
INSERT INTO `service_satisfaction` (`client_id`, `score`) VALUES (3, 5), (1, 4);

-- 7、产品与库存管理
-- 产品表
CREATE TABLE `product_items` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '产品ID',
    `product_code` varchar(50) NOT NULL COMMENT '产品编码',
    `name` varchar(100) NOT NULL COMMENT '产品名称',
    `category` tinyint(1) NOT NULL DEFAULT '1' COMMENT '分类：1=软件,2=服务,3=硬件',
    `price` decimal(12,2) NOT NULL COMMENT '标准价格',
    `unit` varchar(20) DEFAULT NULL COMMENT '单位',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=在售,2=停售,3=即将上市',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_product_code` (`product_code`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '产品表';

-- 库存表
CREATE TABLE `product_inventory` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '库存ID',
    `product_id` int(11) NOT NULL COMMENT '产品ID',
    `quantity` int(11) NOT NULL DEFAULT '0' COMMENT '库存数量',
    `warehouse` varchar(50) DEFAULT '主仓库' COMMENT '仓库',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_product_warehouse` (`product_id`,`warehouse`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '库存表';

-- 库存变动记录表
CREATE TABLE `product_stock_logs` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `product_id` int(11) NOT NULL COMMENT '产品ID',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=入库,2=出库',
    `quantity` int(11) NOT NULL COMMENT '数量',
    `order_id` int(11) DEFAULT NULL COMMENT '关联订单ID',
    `operator_id` int(11) NOT NULL COMMENT '操作人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '库存变动记录表';

-- 供应商表
CREATE TABLE `product_suppliers` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '供应商ID',
    `name` varchar(100) NOT NULL COMMENT '供应商名称',
    `contact` varchar(50) DEFAULT NULL COMMENT '联系人',
    `phone` varchar(20) DEFAULT NULL COMMENT '联系电话',
    `address` varchar(255) DEFAULT NULL COMMENT '地址',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=合作中,0=已终止',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '供应商表';

-- 价格策略表
CREATE TABLE `product_price_rules` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '策略ID',
    `product_id` int(11) NOT NULL COMMENT '产品ID',
    `rule_name` varchar(100) NOT NULL COMMENT '策略名称',
    `client_level` tinyint(1) DEFAULT NULL COMMENT '客户级别：1=VIP,2=普通',
    `discount` decimal(5,2) NOT NULL COMMENT '折扣率(0-100)',
    `start_date` date DEFAULT NULL COMMENT '开始日期',
    `end_date` date DEFAULT NULL COMMENT '结束日期',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=启用,0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '价格策略表';

-- 初始化产品示例数据
INSERT INTO `product_items` (`product_code`, `name`, `category`, `price`, `unit`, `status`) VALUES ('SW001', 'SmartCRM基础版', 1, 5000.00, '套', 1), ('SW002', 'SmartCRM专业版', 1, 15000.00, '套', 1), ('SV001', '实施服务', 2, 10000.00, '次', 1), ('SV002', '技术支持服务', 2, 5000.00, '年', 1), ('HW001', '服务器', 3, 20000.00, '台', 1);

-- 初始化库存示例数据
INSERT INTO `product_inventory` (`product_id`, `quantity`, `warehouse`) VALUES (5, 10, '主仓库'), (1, 50, '主仓库'), (2, 30, '主仓库');

-- 初始化库存变动记录示例数据
INSERT INTO `product_stock_logs` (`product_id`, `type`, `quantity`, `order_id`, `operator_id`) VALUES (5, 1, 15, NULL, 1), (5, 2, 5, 1, 1), (1, 1, 50, NULL, 1);

-- 初始化供应商示例数据
INSERT INTO `product_suppliers` (`name`, `contact`, `phone`, `address`, `status`) VALUES ('戴尔科技', '王经理', '13900000010', '上海市浦东新区张江高科技园区', 1), ('联想集团', '李经理', '13900000011', '北京市海淀区联想大厦', 1);

-- 初始化价格策略示例数据
INSERT INTO `product_price_rules` (`product_id`, `rule_name`, `client_level`, `discount`, `start_date`, `end_date`, `status`) VALUES (1, 'VIP客户折扣', 1, 80.00, '2023-01-01', '2023-12-31', 1), (2, 'VIP客户折扣', 1, 85.00, '2023-01-01', '2023-12-31', 1), (1, '季度促销', NULL, 90.00, '2023-07-01', '2023-09-30', 1);

-- 8、财务管理
-- 收款记录表
CREATE TABLE `finance_receipts` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '收款ID',
    `receipt_no` varchar(50) NOT NULL COMMENT '收款编号',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `order_id` int(11) DEFAULT NULL COMMENT '订单ID',
    `contract_id` int(11) DEFAULT NULL COMMENT '合同ID',
    `amount` decimal(12,2) NOT NULL COMMENT '收款金额',
    `payment_method` varchar(50) NOT NULL COMMENT '付款方式',
    `payment_time` datetime NOT NULL COMMENT '付款时间',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=待确认,2=已确认',
    `creator_id` int(11) NOT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_receipt_no` (`receipt_no`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '收款记录表';

-- 应收账款表
CREATE TABLE `finance_receivables` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '应收ID',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `order_id` int(11) DEFAULT NULL COMMENT '订单ID',
    `amount` decimal(12,2) NOT NULL COMMENT '应收金额',
    `received_amount` decimal(12,2) NOT NULL DEFAULT '0.00' COMMENT '已收金额',
    `due_date` date NOT NULL COMMENT '到期日期',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=未收,2=部分收款,3=已收',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_client_id` (`client_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '应收账款表';

-- 佣金表
CREATE TABLE `finance_commissions` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '佣金ID',
    `user_id` int(11) NOT NULL COMMENT '员工ID',
    `order_id` int(11) DEFAULT NULL COMMENT '订单ID',
    `contract_id` int(11) DEFAULT NULL COMMENT '合同ID',
    `amount` decimal(12,2) NOT NULL COMMENT '佣金金额',
    `rate` decimal(5,2) DEFAULT NULL COMMENT '佣金比例(%)',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=待发放,2=已发放',
    `month` varchar(7) NOT NULL COMMENT '佣金月份：YYYY-MM',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_user_id` (`user_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '佣金表';

-- 预算表
CREATE TABLE `finance_budgets` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '预算ID',
    `department` varchar(50) NOT NULL COMMENT '部门',
    `year` int(4) NOT NULL COMMENT '年份',
    `month` int(2) NOT NULL COMMENT '月份',
    `budget_amount` decimal(12,2) NOT NULL COMMENT '预算金额',
    `actual_amount` decimal(12,2) DEFAULT '0.00' COMMENT '实际金额',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=收入,2=支出',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_department_month` (`department`,`year`,`month`,`type`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '预算表';

-- 对账单表
CREATE TABLE `finance_statements` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '对账单ID',
    `statement_no` varchar(50) NOT NULL COMMENT '对账单编号',
    `client_id` int(11) NOT NULL COMMENT '客户ID',
    `start_date` date NOT NULL COMMENT '开始日期',
    `end_date` date NOT NULL COMMENT '结束日期',
    `total_amount` decimal(12,2) NOT NULL COMMENT '总金额',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=未确认,2=已确认',
    `creator_id` int(11) NOT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_statement_no` (`statement_no`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '对账单表';

ALTER TABLE `finance_statements` 
ADD COLUMN `received_amount` decimal(12,2) NOT NULL DEFAULT '0.00' COMMENT '已收金额' 
AFTER `total_amount`;

-- 初始化收款记录示例数据
INSERT INTO `finance_receipts` (`receipt_no`, `client_id`, `order_id`, `contract_id`, `amount`, `payment_method`, `payment_time`, `status`, `creator_id`) VALUES ('SK20230001', 3, 1, 1, 5000.00, '银行转账', '2023-06-15 10:30:00', 2, 1), ('SK20230002', 1, 2, NULL, 100000.00, '银行转账', '2023-06-20 14:20:00', 1, 1);

-- 初始化应收账款示例数据
INSERT INTO `finance_receivables` (`client_id`, `order_id`, `amount`, `received_amount`, `due_date`, `status`) VALUES (1, 2, 200000.00, 100000.00, '2023-07-31', 2), (2, NULL, 300000.00, 0.00, '2023-08-15', 1);

-- 初始化佣金示例数据
INSERT INTO `finance_commissions` (`user_id`, `order_id`, `contract_id`, `amount`, `rate`, `status`, `month`) VALUES (2, 1, 1, 500.00, 10.00, 2, '2023-06'), (2, 2, NULL, 20000.00, 10.00, 1, '2023-06');

-- 初始化预算示例数据
INSERT INTO `finance_budgets` (`department`, `year`, `month`, `budget_amount`, `actual_amount`, `type`) VALUES ('销售部', 2023, 6, 500000.00, 300000.00, 1), ('市场部', 2023, 6, 100000.00, 80000.00, 2), ('技术部', 2023, 6, 200000.00, 180000.00, 2);

INSERT INTO `finance_statements` (`statement_no`, `client_id`, `start_date`, `end_date`, `total_amount`, `received_amount`, `status`, `creator_id`) VALUES 
('DZ20230601', 1, '2023-06-01', '2023-06-30', 300000.00, 250000.00, 2, 1), 
('DZ20230602', 2, '2023-06-01', '2023-06-30', 300000.00, 0.00, 1, 1);

-- 9、数据分析与报表
-- 报表模板表
CREATE TABLE `report_templates` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '模板ID',
    `name` varchar(100) NOT NULL COMMENT '模板名称',
    `category` tinyint(1) NOT NULL COMMENT '分类：1=客户分析,2=销售分析,3=营销分析,4=满意度分析,5=财务分析',
    `sql_content` text NOT NULL COMMENT 'SQL查询语句',
    `description` varchar(255) DEFAULT NULL COMMENT '模板描述',
    `is_system` tinyint(1) NOT NULL DEFAULT '1' COMMENT '是否系统模板：1=是,0=否',
    `creator_id` int(11) DEFAULT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '报表模板表';

-- 报表记录表
CREATE TABLE `report_records` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `template_id` int(11) NOT NULL COMMENT '模板ID',
    `title` varchar(100) NOT NULL COMMENT '报表标题',
    `params` varchar(255) DEFAULT NULL COMMENT '查询参数(JSON格式)',
    `file_path` varchar(255) DEFAULT NULL COMMENT '导出文件路径',
    `creator_id` int(11) NOT NULL COMMENT '创建人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_template_id` (`template_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '报表记录表';

-- 数据统计表
CREATE TABLE `report_stats` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '统计ID',
    `stat_type` varchar(50) NOT NULL COMMENT '统计类型',
    `dimension` varchar(50) NOT NULL COMMENT '统计维度',
    `dimension_value` varchar(50) NOT NULL COMMENT '维度值',
    `stat_time` varchar(20) NOT NULL COMMENT '统计时间段',
    `value` decimal(12,2) NOT NULL COMMENT '统计值',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_stat_dimension` (`stat_type`,`dimension`,`dimension_value`,`stat_time`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '数据统计表';

-- 自定义仪表盘表
CREATE TABLE `report_dashboards` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '仪表盘ID',
    `name` varchar(100) NOT NULL COMMENT '仪表盘名称',
    `layout` text DEFAULT NULL COMMENT '布局配置(JSON格式)',
    `is_public` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否公开：1=是,0=否',
    `user_id` int(11) NOT NULL COMMENT '用户ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_user_id` (`user_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '自定义仪表盘表';

-- 初始化报表模板示例数据
INSERT INTO `report_templates` (`name`, `category`, `sql_content`, `description`, `is_system`, `creator_id`) VALUES 
('客户增长分析', 1, 'SELECT DATE_FORMAT(create_time, "%Y-%m") as month, COUNT(*) as new_clients FROM crm_clients GROUP BY month', '按月统计新增客户数量', 1, 1), 
('销售业绩分析', 2, 'SELECT u.username, SUM(o.amount) as total_amount FROM order_orders o JOIN sys_users u ON o.creator_id = u.id WHERE o.status > 1 GROUP BY o.creator_id', '统计销售人员订单总金额', 1, 1), 
('营销活动效果分析', 3, 'SELECT c.name, SUM(r.conversion) as conversions, SUM(r.revenue) as revenue FROM mkt_campaigns c LEFT JOIN mkt_results r ON c.id = r.campaign_id GROUP BY c.id', '营销活动转化和收入统计', 1, 1), 
('客户满意度分析', 4, 'SELECT AVG(score) as avg_score FROM service_satisfaction', '客户满意度平均分', 1, 1), 
('财务收款分析', 5, 'SELECT DATE_FORMAT(payment_time, "%Y-%m") as month, SUM(amount) as total_received FROM finance_receipts WHERE status = 2 GROUP BY month', '按月统计已确认收款金额', 1, 1);

-- 初始化报表记录示例数据
INSERT INTO `report_records` (`template_id`, `title`, `params`, `file_path`, `creator_id`) VALUES 
(1, '2023年上半年客户增长分析', '{"start_date": "2023-01-01", "end_date": "2023-06-30"}', '/reports/client_growth_202301_202306.xlsx', 1), 
(2, '2023年6月销售业绩报表', '{"month": "2023-06"}', '/reports/sales_performance_202306.xlsx', 1);

-- 初始化数据统计示例数据
INSERT INTO `report_stats` (`stat_type`, `dimension`, `dimension_value`, `stat_time`, `value`) VALUES 
('client_growth', 'month', '2023-05', '2023-05', 15.00), 
('client_growth', 'month', '2023-06', '2023-06', 22.00), 
('sales_performance', 'user', '1', '2023-06', 500000.00), 
('sales_performance', 'user', '2', '2023-06', 300000.00), 
('client_satisfaction', 'month', '2023-06', '2023-06', 4.50);

-- 初始化自定义仪表盘示例数据
INSERT INTO `report_dashboards` (`name`, `layout`, `is_public`, `user_id`) VALUES 
('销售部门概览', '{"widgets": [{"type": "chart", "templateId": 2, "position": {"x": 0, "y": 0, "w": 6, "h": 4}}, {"type": "chart", "templateId": 5, "position": {"x": 6, "y": 0, "w": 6, "h": 4}}]}', 1, 1), 
('个人工作台', '{"widgets": [{"type": "chart", "templateId": 1, "position": {"x": 0, "y": 0, "w": 12, "h": 4}}]}', 0, 2);

-- 10、任务与日程管理
-- 任务表（合并个人任务和团队任务）
CREATE TABLE `task_todos` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '任务ID',
  `title` varchar(100) NOT NULL COMMENT '标题',
  `type` tinyint(1) DEFAULT '1' COMMENT '类型：1个人，2团队',
  `priority` tinyint(1) DEFAULT '2' COMMENT '优先级：1低，2中，3高',
  `status` tinyint(1) DEFAULT '1' COMMENT '状态：1待处理，2已完成',
  `end_time` datetime DEFAULT NULL COMMENT '截止时间',
  `user_id` int(11) NOT NULL COMMENT '负责人ID',
  `team_id` int(11) DEFAULT NULL COMMENT '团队ID',
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='任务管理';

-- 日程表
CREATE TABLE `task_schedules` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '日程ID',
  `title` varchar(100) NOT NULL COMMENT '标题',
  `type` tinyint(1) DEFAULT '1' COMMENT '类型：1拜访，2会议，3其他',
  `client_id` int(11) DEFAULT NULL COMMENT '客户ID',
  `start_time` datetime NOT NULL COMMENT '开始时间',
  `end_time` datetime NOT NULL COMMENT '结束时间',
  `location` varchar(200) DEFAULT NULL COMMENT '地点',
  `status` tinyint(1) DEFAULT '1' COMMENT '状态：1未完成，2已完成',
  `user_id` int(11) NOT NULL COMMENT '用户ID',
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='日程安排';

-- 提醒表
CREATE TABLE `task_reminders` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '提醒ID',
  `title` varchar(100) NOT NULL COMMENT '标题',
  `type` tinyint(1) DEFAULT '1' COMMENT '类型：1系统，2邮件，3短信',
  `related_id` int(11) DEFAULT NULL COMMENT '关联ID',
  `related_type` varchar(20) DEFAULT NULL COMMENT '关联类型：todo,schedule,client',
  `remind_time` datetime NOT NULL COMMENT '提醒时间',
  `user_id` int(11) NOT NULL COMMENT '用户ID',
  `status` tinyint(1) DEFAULT '1' COMMENT '状态：1未读，2已读',
  `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='提醒通知';

-- 示例数据
INSERT INTO `task_todos` (`title`, `type`, `priority`, `status`, `end_time`, `user_id`, `team_id`, `create_time`) VALUES ('准备腾讯客户方案', 1, 3, 1, '2023-10-05 18:00:00', 1, NULL, '2023-09-30 10:00:00'), ('团队周报汇总', 2, 2, 1, '2023-10-06 17:00:00', 2, 1, '2023-10-01 14:30:00'), ('阿里巴巴合同审核', 1, 3, 1, '2023-10-04 18:00:00', 1, NULL, '2023-10-01 09:15:00');

INSERT INTO `task_schedules` (`title`, `type`, `client_id`, `start_time`, `end_time`, `location`, `status`, `user_id`, `create_time`) VALUES ('腾讯客户拜访', 1, 1, '2023-10-10 10:00:00', '2023-10-10 12:00:00', '深圳市南山区腾讯大厦', 1, 1, '2023-10-01 08:30:00'), ('销售团队会议', 2, NULL, '2023-10-07 14:00:00', '2023-10-07 16:00:00', '公司会议室A', 1, 1, '2023-10-01 11:20:00'), ('阿里巴巴合同签署', 2, 2, '2023-10-15 13:30:00', '2023-10-15 15:00:00', '杭州市余杭区', 1, 2, '2023-10-02 09:45:00');

INSERT INTO `task_reminders` (`title`, `type`, `related_id`, `related_type`, `remind_time`, `user_id`, `status`, `create_time`) VALUES ('待办事项提醒', 1, 1, 'todo', '2023-10-04 09:00:00', 1, 1, '2023-10-01 09:00:00'), ('客户拜访提醒', 2, 1, 'schedule', '2023-10-09 18:00:00', 1, 1, '2023-10-01 08:35:00'), ('合同到期提醒', 3, 3, 'contract', '2023-10-05 09:00:00', 2, 1, '2023-10-01 09:30:00');


-- 11、人员绩效与KPI
-- 团队表(包含成员关系)
CREATE TABLE `perf_teams` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '团队ID',
    `team_name` varchar(50) NOT NULL COMMENT '团队名称',
    `leader_id` int(11) NOT NULL COMMENT '团队负责人ID', 
    `members` varchar(255) DEFAULT NULL COMMENT '成员ID,以逗号分隔',
    `department` varchar(50) NOT NULL COMMENT '所属部门',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '团队表';

-- 绩效考核表(合并目标和考核)
CREATE TABLE `perf_assessments` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '考核ID',
    `user_id` int(11) NOT NULL COMMENT '用户ID',
    `team_id` int(11) DEFAULT NULL COMMENT '团队ID(团队考核)',
    `year` int(4) NOT NULL COMMENT '年份',
    `month` int(2) NOT NULL COMMENT '月份',
    `target_amount` decimal(12,2) DEFAULT NULL COMMENT '目标销售额',
    `actual_amount` decimal(12,2) DEFAULT '0.00' COMMENT '实际销售额',
    `target_clients` int(11) DEFAULT NULL COMMENT '目标客户数',
    `actual_clients` int(11) DEFAULT '0' COMMENT '实际客户数',
    `score` decimal(5,2) DEFAULT NULL COMMENT '考核得分',
    `level` tinyint(1) DEFAULT NULL COMMENT '等级：1=A,2=B,3=C,4=D,5=E',
    `comment` varchar(255) DEFAULT NULL COMMENT '评语',
    `assessor_id` int(11) DEFAULT NULL COMMENT '考核人ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_user_month` (`user_id`,`year`,`month`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '绩效考核表';

-- 激励记录表
CREATE TABLE `perf_incentives` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '激励ID',
    `user_id` int(11) NOT NULL COMMENT '用户ID',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=提成,2=奖金,3=其他奖励',
    `amount` decimal(12,2) NOT NULL COMMENT '金额',
    `description` varchar(100) NOT NULL COMMENT '说明',
    `year` int(4) NOT NULL COMMENT '年份',
    `month` int(2) NOT NULL COMMENT '月份',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=待发放,2=已发放',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '激励记录表';

-- 初始化团队示例数据
INSERT INTO `perf_teams` (`team_name`, `leader_id`, `members`, `department`) VALUES ('销售一组', 2, '2,4,5', '销售部'), ('销售二组', 3, '3,6,7', '销售部');

-- 初始化绩效考核示例数据
INSERT INTO `perf_assessments` (`user_id`, `team_id`, `year`, `month`, `target_amount`, `actual_amount`, `target_clients`, `actual_clients`, `score`, `level`, `assessor_id`) VALUES (2, 1, 2023, 6, 300000.00, 320000.00, 5, 6, 95.00, 1, 1), (3, 2, 2023, 6, 300000.00, 280000.00, 5, 4, 88.00, 2, 1);

-- 初始化激励记录示例数据
INSERT INTO `perf_incentives` (`user_id`, `type`, `amount`, `description`, `year`, `month`, `status`) VALUES (2, 1, 32000.00, '6月销售提成', 2023, 6, 2), (3, 1, 28000.00, '6月销售提成', 2023, 6, 2), (2, 2, 5000.00, '季度销售冠军奖金', 2023, 6, 2);